tensap.approximation.learning package
=====================================

Submodules
----------

tensap.approximation.learning.learning module
---------------------------------------------

.. automodule:: tensap.approximation.learning.learning
   :members:
   :undoc-members:
   :show-inheritance:

tensap.approximation.learning.linear\_model\_learning module
------------------------------------------------------------

.. automodule:: tensap.approximation.learning.linear_model_learning
   :members:
   :undoc-members:
   :show-inheritance:

tensap.approximation.learning.linear\_model\_learning\_custom\_loss module
--------------------------------------------------------------------------

.. automodule:: tensap.approximation.learning.linear_model_learning_custom_loss
   :members:
   :undoc-members:
   :show-inheritance:

tensap.approximation.learning.linear\_model\_learning\_density\_l2 module
-------------------------------------------------------------------------

.. automodule:: tensap.approximation.learning.linear_model_learning_density_l2
   :members:
   :undoc-members:
   :show-inheritance:

tensap.approximation.learning.linear\_model\_learning\_square\_loss module
--------------------------------------------------------------------------

.. automodule:: tensap.approximation.learning.linear_model_learning_square_loss
   :members:
   :undoc-members:
   :show-inheritance:

tensap.approximation.learning.loss\_functions module
----------------------------------------------------

.. automodule:: tensap.approximation.learning.loss_functions
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: tensap.approximation.learning
   :members:
   :undoc-members:
   :show-inheritance:
